pub struct Whirlpool {Show 20 fields
pub discriminator: [u8; 8],
pub whirlpool_config: Pubkey,
pub whirlpool_bump: u8,
pub tick_spacing: u16,
pub fee_tier_index: u16,
pub fee_rate: u16,
pub protocol_fee_rate: u16,
pub liquidity: u128,
pub sqrt_price: u128,
pub tick_current_index: i32,
pub protocol_fee_owed_a: u64,
pub protocol_fee_owed_b: u64,
pub token_a_mint: Pubkey,
pub token_a_vault: Pubkey,
pub fee_growth_global_a: u128,
pub token_b_mint: Pubkey,
pub token_b_vault: Pubkey,
pub fee_growth_global_b: u128,
pub reward_last_updated_timestamp: u64,
pub reward_infos: [WhirlpoolRewardInfo; 3],
}Fields
discriminator: [u8; 8]whirlpool_config: Pubkeywhirlpool_bump: u8tick_spacing: u16fee_tier_index: u16fee_rate: u16protocol_fee_rate: u16liquidity: u128sqrt_price: u128tick_current_index: i32protocol_fee_owed_a: u64protocol_fee_owed_b: u64token_a_mint: Pubkeytoken_a_vault: Pubkeyfee_growth_global_a: u128token_b_mint: Pubkeytoken_b_vault: Pubkeyfee_growth_global_b: u128reward_last_updated_timestamp: u64reward_infos: [WhirlpoolRewardInfo; 3]Trait Implementations
Sourceimpl BorshDeserialize for Whirlpool
impl BorshDeserialize for Whirlpool
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Whirlpool
impl BorshSerialize for Whirlpool
impl StructuralPartialEq for Whirlpool